@@ -28,7 +28,7 @@ pub struct ModuleContext<'m> {
     pub literals: Map<_Any, String>,
     pub typedefs: Vec<Item>,
     pub functiondefs: Vec<Item>,
-    pub mode: ModuleContextMode,
+    pub mode: Option<ModuleContextMode>,
 }
 
 pub struct FunctionContext<'a, 'm> {
@@ -62,7 +62,7 @@ impl<'m> ModuleContext<'m> {
             literals: Map::new(),
             typedefs: Vec::new(),
             functiondefs: Vec::new(),
-            mode: ModuleContextMode::TargetIOValue,
+            mode: None,
         }
     }
 
@@ -105,15 +105,19 @@ impl<'m> ModuleContext<'m> {
         }
     }
 
+    pub fn mode(&self) -> ModuleContextMode {
+        self.mode.expect("defined ModuleContextMode")
+    }
+
     pub fn target(&self) -> &'static str {
-        match self.mode {
+        match self.mode() {
             ModuleContextMode::TargetIOValue => "preserves::value::IOValue",
             ModuleContextMode::TargetAny => "_Any",
         }
     }
 
     pub fn target_prefix(&self) -> &'static str {
-        match self.mode {
+        match self.mode() {
             ModuleContextMode::TargetIOValue => "_io_",
             ModuleContextMode::TargetAny => "_any_",
         }
