@@ -7,6 +7,17 @@ use super::context::{ModuleContextMode, ModuleContext, FunctionContext};
 use super::names;
 use super::types::*;
 
+#[derive(Debug)]
+pub struct ParserPlugin;
+
+impl compiler::Plugin for ParserPlugin {
+    fn generate(&self, module_ctxt: &mut ModuleContext, definition_name: &str, definition: &Definition) {
+        if module_ctxt.mode.is_some() {
+            gen_definition_parser(module_ctxt, definition_name, definition)
+        }
+    }
+}
+
 pub fn gen_definition_parser(m: &mut ModuleContext, n: &str, d: &Definition) {
     m.define_function(
         n,
@@ -107,7 +118,7 @@ fn simple_pattern_parser(
     let dest = ctxt.gentempname();
     match p {
         SimplePattern::Any => {
-            match ctxt.m.mode {
+            match ctxt.m.mode() {
                 ModuleContextMode::TargetIOValue =>
                     ctxt.define_atom(body, &dest, item(seq!["_support::decode_embedded", parens![src.to_owned()], "?"])),
                 ModuleContextMode::TargetAny =>
@@ -129,7 +140,7 @@ fn simple_pattern_parser(
             dest
         },
         SimplePattern::Embedded { .. } => {
-            match ctxt.m.mode {
+            match ctxt.m.mode() {
                 ModuleContextMode::TargetIOValue =>
                     ctxt.define_atom(body, &dest, item(seq![
                         "std::sync::Arc::new(_Dom::try_from",
