@@ -31,6 +31,19 @@ pub enum TField {
 #[derive(Debug, PartialEq, Eq, PartialOrd, Ord, Clone)]
 pub struct TRecord(pub Vec<(String, TField)>);
 
+#[derive(Debug)]
+pub struct TypePlugin;
+
+impl compiler::Plugin for TypePlugin {
+    fn generate(&self, m: &mut ModuleContext, n: &str, d: &Definition) {
+        if m.mode.is_none() {
+            m.define_type(item(render_definition_type(m, n, &definition_type(d))));
+            m.define_type(item(seq![
+                "impl preserves::value::Domain for ", names::render_constructor(n), " {}"]));
+        }
+    }
+}
+
 pub fn definition_type(d: &Definition) -> TDefinition {
     match d {
         Definition::Or { pattern_0, pattern_1, pattern_n } =>
